%define major		2
%define libname		%mklibname %{name} %{major}
%define develname	%mklibname %{name} -d

# comment out if not pre release
#define prel	rc7

# release to bump
%define rel	1

%global std	C++17

Name:		opendht
Version:	2.5.5
Release:	%mkrel %{?prel:0.%prel.}%{rel}
Summary:	A %{std} Distributed Hash Table implementation
Group:		System/Libraries
License:	GPLv3+
Url:		https://github.com/savoirfairelinux/opendht
Source0:	https://github.com/savoirfairelinux/opendht/archive/v%{version}%{?prel}/%{name}-%{version}%{?prel}.tar.gz
# Upstream patches

# Mageia patches

BuildRequires:	cmake
BuildRequires:	asio-devel
BuildRequires:	restinio-devel
BuildRequires:	pkgconfig(cppunit)
BuildRequires:	pkgconfig(readline)
BuildRequires:	pkgconfig(gnutls)
BuildRequires:	pkgconfig(jsoncpp)
BuildRequires:	pkgconfig(libargon2)
BuildRequires:	pkgconfig(msgpack)
BuildRequires:	pkgconfig(nettle)
BuildRequires:	pkgconfig(libsystemd)
BuildRequires:	pkgconfig(python3)
BuildRequires:	pkgconfig(openssl)
BuildRequires:	python3dist(cython)

Requires(post):		rpm-helper >= %{rpmhelper_required_version}
Requires(preun):	rpm-helper >= %{rpmhelper_required_version}

%description
A lightweight %{std} Distributed Hash Table implementation.

#----------------------------------------------------

%package -n	%{libname}
Summary:	A %{std} Distributed Hash Table implementation
Group:		System/Libraries

%description -n	%{libname}
A lightweight %{std} Distributed Hash Table implementation.
This package contains library files for %{name}.

#----------------------------------------------------

%package -n	%{develname}
Summary:	Development files for %{name}
Group:		Development/C
Requires:	%{libname} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Provides:	lib%{name}-devel = %{version}-%{release}
# For #includes
Requires:	asio-devel
Requires:	restinio-devel

%description -n	%{develname}
The %{develname} package contains libraries and header files for
developing applications that use %{name}.

#----------------------------------------------------

%prep
%autosetup -p1 -n %{name}-%{version}%{?prel}

%build
%cmake \
	-DOPENDHT_PYTHON:BOOL=OFF \
	-DOPENDHT_STATIC:BOOL=OFF \
	-DOPENDHT_SYSTEMD:BOOL=ON \
	-DOPENDHT_SYSTEMD_UNIT_FILE_LOCATION:PATH=%{_unitdir} \
	-DOPENDHT_PROXY_SERVER:BOOL=ON \
	-DOPENDHT_PROXY_CLIENT:BOOL=ON \
	-DOPENDHT_PUSH_NOTIFICATIONS:BOOL=ON

%cmake_build

%install
%cmake_install

%post
%_post_service dhtnode

%preun
%_preun_service dhtnode

%files
%doc README.md
%license COPYING
%{_sysconfdir}/dhtnode.conf
%{_unitdir}/dhtnode.service
%{_bindir}/dhtchat
%{_bindir}/dhtnode
%{_bindir}/dhtscanner
%{_mandir}/man1/dhtnode.1.*

%files -n %{libname}
%{_libdir}/lib%{name}.so.%{major}{,.*}

%files -n %{develname}
%{_includedir}/%{name}/
%{_includedir}/%{name}.h
%{_libdir}/cmake/%{name}/
%{_libdir}/pkgconfig/%{name}.pc
%{_libdir}/lib%{name}.so


%changelog
* Fri Jun 09 2023 wally <wally> 2.5.5-1.mga9
+ Revision: 1961461
- new version 2.5.5

* Wed Jun 07 2023 wally <wally> 2.5.1-3.mga9
+ Revision: 1961271
- new version 2.5.1

* Sat Jan 21 2023 wally <wally> 2.4.10-3.mga9
+ Revision: 1934672
- rebuild for restinio 0.6.17

* Sat Oct 08 2022 papoteur <papoteur> 2.4.10-2.mga9
+ Revision: 1895585
- Rebuild for libfmt9

* Wed Sep 14 2022 wally <wally> 2.4.10-1.mga9
+ Revision: 1888162
- new version 2.4.10

* Thu Jul 28 2022 wally <wally> 2.4.9-1.mga9
+ Revision: 1872710
- new version 2.4.9

* Wed Apr 06 2022 wally <wally> 2.4.0-1.mga9
+ Revision: 1846557
- new version 2.4.0

* Wed Mar 30 2022 umeabot <umeabot> 2.3.0-3.mga9
+ Revision: 1833634
- Mageia 9 Mass Rebuild

* Sat Oct 02 2021 wally <wally> 2.3.0-2.mga9
+ Revision: 1747423
- rebuild for openssl 3.0.0

* Sun Aug 01 2021 wally <wally> 2.3.0-1.mga9
+ Revision: 1738448
- new version 2.3.0

* Thu Jun 24 2021 wally <wally> 2.2.0-1.mga9
+ Revision: 1732139
- new version 2.2.0

* Sun May 30 2021 wally <wally> 2.2.0-0.rc7.1.mga9
+ Revision: 1728891
- new version 2.2.0rc7

* Sun Mar 21 2021 wally <wally> 2.2.0-0.rc2.1.mga9
+ Revision: 1706666
- new version 2.2.0rc2

* Thu Feb 25 2021 daviddavid <daviddavid> 2.1.10-1.mga9
+ Revision: 1690906
- new version: 2.1.10
- remove merged upstream patches

* Fri Dec 25 2020 wally <wally> 2.1.9.5-4.mga8
+ Revision: 1663731
- update summaries and descriptions

* Thu Dec 24 2020 wally <wally> 2.1.9.5-3.mga8
+ Revision: 1663532
- enable proxy server/client support for jami-daemon (former ring-daemon)

* Thu Dec 24 2020 wally <wally> 2.1.9.5-2.mga8
+ Revision: 1663419
- add patches from upstream git

* Thu Dec 24 2020 wally <wally> 2.1.9.5-1.mga8
+ Revision: 1663361
- new version 2.1.9.5

* Sun Nov 29 2020 luigiwalser <luigiwalser> 2.1.6-2.mga8
+ Revision: 1650434
- rebuild for nettle

* Sun Nov 08 2020 daviddavid <daviddavid> 2.1.6-1.mga8
+ Revision: 1643611
- new version: 2.1.6

* Thu Jun 25 2020 daviddavid <daviddavid> 2.1.4-1.mga8
+ Revision: 1599209
- new version: 2.1.4

* Tue May 26 2020 daviddavid <daviddavid> 2.1.3-1.mga8
+ Revision: 1587677
- new version: 2.1.3

* Sun May 24 2020 wally <wally> 2.1.2-2.mga8
+ Revision: 1587416
- add patch to fix pkg-config .pc file
- add missing devel pkg requires for asio and restinio

* Sun May 24 2020 wally <wally> 2.1.2-1.mga8
+ Revision: 1587351
- new version 2.1.2

* Sat May 23 2020 daviddavid <daviddavid> 2.1.1-1.mga8
+ Revision: 1586960
- new version: 2.1.1
- now libmajor is 2

* Sun May 10 2020 daviddavid <daviddavid> 1.8.1-5.mga8
+ Revision: 1582756
- rebuild for updated python deps

* Wed Feb 19 2020 umeabot <umeabot> 1.8.1-4.mga8
+ Revision: 1542727
- Mageia 8 Mass Rebuild

* Mon Jan 06 2020 luigiwalser <luigiwalser> 1.8.1-3.mga8
+ Revision: 1476815
- rebuild for readline
+ wally <wally>
- build with new cmake macros

* Tue Oct 01 2019 daviddavid <daviddavid> 1.8.1-2.mga8
+ Revision: 1448573
- rebuild for new nettle 3.5.1

* Tue Jan 01 2019 daviddavid <daviddavid> 1.8.1-1.mga7
+ Revision: 1348061
- new version: 1.8.1

* Tue Dec 25 2018 daviddavid <daviddavid> 1.8.0-1.mga7
+ Revision: 1344962
- new version: 1.8.0

* Sun Sep 23 2018 umeabot <umeabot> 1.7.4-2.mga7
+ Revision: 1300009
- Mageia 7 Mass Rebuild

* Sun Aug 19 2018 daviddavid <daviddavid> 1.7.4-1.mga7
+ Revision: 1252722
- new version: 1.7.4

* Sun Jun 03 2018 daviddavid <daviddavid> 1.7.2-1.mga7
+ Revision: 1233817
- new version: 1.7.2

* Sat Mar 03 2018 daviddavid <daviddavid> 1.6.0-1.mga7
+ Revision: 1206244
- new version: 1.6.0

* Thu Jan 04 2018 daviddavid <daviddavid> 1.5.0-2.mga7
+ Revision: 1190087
- rebuild for new argon2 20171227

* Sun Dec 17 2017 daviddavid <daviddavid> 1.5.0-1.mga7
+ Revision: 1183003
- new version: 1.5.0

* Sat Sep 02 2017 daviddavid <daviddavid> 1.3.6-1.mga7
+ Revision: 1150697
- new version: 1.3.6

* Mon Jul 24 2017 daviddavid <daviddavid> 1.3.5-1.mga7
+ Revision: 1130158
- new version: 1.3.5
- use system libargon2
- install the systemd module

* Sat Jun 03 2017 akien <akien> 1.3.3-1.mga6
+ Revision: 1106076
- Version 1.3.3 (fixes underlinking of msgpack)

* Mon Jan 02 2017 daviddavid <daviddavid> 1.2.1-3.mga6
+ Revision: 1079677
- do not build on armv5tl

* Sun Jan 01 2017 neoclust <neoclust> 1.2.1-2.mga6
+ Revision: 1079446
- Use a newer git snapshot ( needed by ring-daemon )

* Sun Jan 01 2017 daviddavid <daviddavid> 1.2.1-1.mga6
+ Revision: 1079238
- initial package opendht

